(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-core'), require('polythene-theme')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-core', 'polythene-theme'], factory) :
  (factory((global.polythene = {}),global['polythene-core'],global['polythene-theme']));
}(this, (function (exports,polytheneCore,polytheneTheme) { 'use strict';

  var listTileClasses = {
    component: "pe-list-tile",

    // elements
    content: "pe-list-tile__content",
    highSubtitle: "pe-list-tile__high-subtitle",
    primary: "pe-list-tile__primary",
    secondary: "pe-list-tile__secondary",
    subtitle: "pe-list-tile__subtitle",
    title: "pe-list-tile__title",
    contentFront: "pe-list-tile__content-front",

    // states
    compact: "pe-list-tile--compact",
    compactFront: "pe-list-tile--compact-front",
    disabled: "pe-list-tile--disabled",
    hasFront: "pe-list-tile--front",
    hasHighSubtitle: "pe-list-tile--high-subtitle",
    hasSubtitle: "pe-list-tile--subtitle",
    header: "pe-list-tile--header",
    hoverable: "pe-list-tile--hoverable",
    selectable: "pe-list-tile--selectable",
    selected: "pe-list-tile--selected",
    highlight: "pe-list-tile--highlight",
    sticky: "pe-list-tile--sticky",
    navigation: "pe-list-tile--navigation"
  };

  var classes = {
    component: "pe-menu",

    // elements
    content: "pe-menu__content",
    placeholder: "pe-menu__placeholder",
    target: "pe-menu__target",

    // states
    permanent: "pe-menu--permanent",
    fullHeight: "pe-menu--full-height",
    floating: "pe-menu--floating",
    visible: "pe-menu--visible",
    width_auto: "pe-menu--width-auto",
    width_n: "pe-menu--width-",

    // lookup
    listTile: listTileClasses.component,
    selectedListTile: listTileClasses.selected
  };

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var getElement = function getElement(vnode) {
    return vnode.attrs.element || "div";
  };

  var DEFAULT_OFFSET_H = 0;
  var DEFAULT_TYPE = "floating";
  var MIN_SIZE = 1.5;
  var OFFSET_V = -8;
  var SHADOW_Z = 1;

  var positionMenu = function positionMenu(state, attrs) {
    if (polytheneCore.isServer) {
      return;
    }
    var targetEl = document.querySelector(attrs.target);
    if (!targetEl) {
      return;
    }
    var offsetH = attrs.offset !== undefined ? attrs.offset : DEFAULT_OFFSET_H;
    var menuEl = state.dom();
    if (!menuEl) {
      return;
    }
    var contentEl = state.dom().querySelector("." + classes.content);
    var origin = attrs.origin || "top-left";
    var positionOffset = 0;
    if (attrs.reposition) {
      var firstItem = contentEl.querySelectorAll("." + classes.listTile)[0];
      var selectedItem = contentEl.querySelector("." + classes.selectedListTile);
      if (firstItem && selectedItem) {
        // calculate v position: menu should shift upward relative to the first item
        var firstItemRect = firstItem.getBoundingClientRect();
        var selectedItemRect = selectedItem.getBoundingClientRect();
        positionOffset = selectedItemRect.top - firstItemRect.top;
      }
      // align to middle of target
      var alignEl = selectedItem || firstItem;
      var alignRect = alignEl.getBoundingClientRect();
      var _targetRect = targetEl.getBoundingClientRect();
      var heightDiff = alignRect.height - _targetRect.height;
      positionOffset += heightDiff / 2;
    }
    var targetRect = targetEl.getBoundingClientRect();
    if (menuEl.parentNode) {
      var parentRect = menuEl.parentNode.getBoundingClientRect();
      var alignLeft = function alignLeft() {
        return menuEl.style.left = targetRect.left - parentRect.left + offsetH + "px";
      };
      var alignRight = function alignRight() {
        return menuEl.style.right = targetRect.right - parentRect.right + offsetH + "px";
      };
      var alignTop = function alignTop() {
        return menuEl.style.top = targetRect.top - parentRect.top - positionOffset + OFFSET_V + "px";
      };
      var alignBottom = function alignBottom() {
        return menuEl.style.bottom = targetRect.bottom - parentRect.bottom - positionOffset + "px";
      };
      var alignFn = {
        "top-left": function topLeft() {
          return alignTop() && alignLeft();
        },
        "top-right": function topRight() {
          return alignTop() && alignRight();
        },
        "bottom-left": function bottomLeft() {
          return alignBottom() && alignLeft();
        },
        "bottom-right": function bottomRight() {
          return alignBottom() && alignRight();
        }
      };
      alignFn[origin].call();
    }
  };

  var transitionOptions = function transitionOptions(state, attrs, isShow) {
    return {
      state: state,
      attrs: attrs,
      isShow: isShow,
      beforeTransition: isShow ? function () {
        return positionMenu(state, attrs);
      } : null,
      domElements: {
        el: state.dom()
      },
      showClass: classes.visible
    };
  };

  var showMenu = function showMenu(state, attrs) {
    return polytheneCore.transitionComponent(transitionOptions(state, attrs, true));
  };

  var hideMenu = function hideMenu(state, attrs) {
    return polytheneCore.transitionComponent(transitionOptions(state, attrs, false));
  };

  var unifySize = function unifySize(size) {
    return size < MIN_SIZE ? MIN_SIZE : size;
  };

  var widthClass = function widthClass(size) {
    return classes.width_n + size.toString().replace(".", "-");
  };

  var handleSubscriptions = function handleSubscriptions(vnode, which) {
    var state = vnode.state;
    var attrs = vnode.attrs;

    if (which === "mount") {
      polytheneCore.subscribe("resize", state.update);
      polytheneCore.subscribe("keydown", state.handleEscape);
      setTimeout(function () {
        state.activateDismissTap();
        showMenu(state, attrs);
      }, 0);
    } else {
      polytheneCore.unsubscribe("resize", state.update);
      polytheneCore.unsubscribe("keydown", state.handleEscape);
      state.deActivateDismissTap();
    }
  };

  var getInitialState = function getInitialState(vnode, createStream) {
    var dom = createStream(null);
    var visible = createStream(false);
    var transitioning = createStream(false);
    return {
      dom: dom,
      visible: visible,
      transitioning: transitioning,
      activateDismissTap: undefined, // set in onMount
      deActivateDismissTap: undefined, // set in onMount
      handleDismissTap: undefined, // set in onMount
      handleEscape: undefined, // set in onMount
      update: undefined, // set in onMount
      redrawOnUpdate: createStream.merge([transitioning])
    };
  };

  var onMount = function onMount(vnode) {
    if (!vnode.dom) {
      return;
    }
    var state = vnode.state;
    var attrs = vnode.attrs;
    state.dom(vnode.dom);

    if (!attrs.permanent) {
      state.handleDismissTap = function (e) {
        if (e.target === state.dom()) {
          return;
        }
        if (e.defaultPrevented) {
          // clicked on .pe-menu__content
          hideMenu(state, attrs);
        } else {
          hideMenu(state, _extends({}, attrs, {
            hideDelay: 0
          }));
        }
      };

      state.update = function () {
        positionMenu(state, attrs);
      };

      state.activateDismissTap = function () {
        if (polytheneCore.isTouch) {
          document.addEventListener("touchstart", state.handleDismissTap);
        } else {
          document.addEventListener("click", state.handleDismissTap);
        }
      };

      state.deActivateDismissTap = function () {
        if (polytheneCore.isTouch) {
          document.removeEventListener("touchstart", state.handleDismissTap);
        } else {
          document.removeEventListener("click", state.handleDismissTap);
        }
      };

      state.handleEscape = function (e) {
        if (e.key === "Escape" || e.key === "Esc") {
          hideMenu(state, _extends({}, attrs, { hideDelay: 0 }));
        }
      };

      handleSubscriptions(vnode, "mount");
    }
  };

  var onUnMount = function onUnMount(vnode) {
    var attrs = vnode.attrs;
    if (!attrs.permanent) {
      handleSubscriptions(vnode, "unmount");
    }
  };

  var createProps = function createProps(vnode, _ref) {
    var k = _ref.keys;

    var attrs = vnode.attrs;
    var type = attrs.type || DEFAULT_TYPE;
    return _extends({}, polytheneCore.filterSupportedAttributes(attrs), {
      className: [classes.component, attrs.permanent ? classes.permanent : null, attrs.fullHeight ? classes.fullHeight : null, type === "floating" ? classes.floating : null, attrs.target ? classes.target : null, attrs.size ? widthClass(unifySize(attrs.size)) : null, attrs.tone === "dark" ? "pe-dark-tone" : null, attrs.tone === "light" ? "pe-light-tone" : null, attrs.className || attrs[k.class]].join(" ")
    });
  };

  var createContent = function createContent(vnode, _ref2) {
    var _h;

    var h = _ref2.renderer,
        k = _ref2.keys,
        Shadow = _ref2.Shadow;

    var attrs = vnode.attrs;
    var z = attrs.z !== undefined ? attrs.z : SHADOW_Z;
    return h("div", (_h = {
      className: classes.content
    }, _defineProperty(_h, k.onclick, function (e) {
      return e.preventDefault();
    }), _defineProperty(_h, "style", attrs.style), _h), [z > 0 && h(Shadow, {
      z: z,
      animated: true
    }), attrs.content ? attrs.content : vnode.children]);
  };

  var menu = /*#__PURE__*/Object.freeze({
    getElement: getElement,
    getInitialState: getInitialState,
    onMount: onMount,
    onUnMount: onUnMount,
    createProps: createProps,
    createContent: createContent
  });

  var rgba = function rgba(colorStr) {
    var opacity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 1;
    return "rgba(" + colorStr + ", " + opacity + ")";
  };

  var vars = {
    sizes: [1, 1.5, 2, 3, 4, 5, 6, 7],
    min_size: 1.5,
    max_size_small_screen: 5,
    size_factor: polytheneTheme.vars.grid_unit_menu,
    border_radius: polytheneTheme.vars.unit_block_border_radius,

    animation_delay: "0s",
    animation_duration: ".220s",
    animation_timing_function: "ease-in-out",
    animation_hide_css: "opacity: 0;",
    animation_show_css: "opacity: 1;",

    color_light_background: rgba(polytheneTheme.vars.color_light_background),
    color_dark_background: rgba(polytheneTheme.vars.color_dark_background)
    // text colors are set by content, usually list tiles
  };

  exports.coreMenu = menu;
  exports.vars = vars;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-core-menu.js.map
