(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('polythene-theme'), require('polythene-core-css'), require('polythene-core-slider')) :
  typeof define === 'function' && define.amd ? define(['exports', 'polythene-theme', 'polythene-core-css', 'polythene-core-slider'], factory) :
  (factory((global.polythene = {}),global['polythene-theme'],global['polythene-core-css'],global['polythene-core-slider']));
}(this, (function (exports,polytheneTheme,polytheneCoreCss,polytheneCoreSlider) { 'use strict';

  var classes = {
    component: "pe-slider",

    // elements
    control: "pe-slider__control",
    label: "pe-slider__label",
    pin: "pe-slider__pin",
    thumb: "pe-slider__thumb",
    tick: "pe-slider__ticks-tick",
    ticks: "pe-slider__ticks",
    track: "pe-slider__track",
    trackBar: "pe-slider__track-bar",
    trackBarValue: "pe-slider__track-bar-value",
    trackPart: "pe-slider__track-part",
    trackPartRest: "pe-slider__track-rest",
    trackPartValue: "pe-slider__track-value",

    // states
    hasFocus: "pe-slider--focus",
    hasPin: "pe-slider--pin",
    hasTicks: "pe-slider--ticks",
    hasTrack: "pe-slider--track",
    isActive: "pe-slider--active",
    isAtMin: "pe-slider--min",
    isDisabled: "pe-slider--disabled"
  };

  function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  // const positionBorder = (thumbSize, borderWidth) => ({
  //   borderWidth: borderWidth + "px",
  //   width: (thumbSize - 2 * borderWidth) + "px",
  //   height: (thumbSize - 2 * borderWidth) + "px",
  //   left: "2px",
  //   top: "2px"
  // });

  var positionBorder = function positionBorder(size, borderWidth, isDisabled) {
    var thumbSize = isDisabled ? size - 2 * borderWidth : size;
    return {
      borderWidth: borderWidth + "px",
      width: thumbSize + "px",
      height: thumbSize + "px",
      left: size - thumbSize + "px",
      top: size - thumbSize + "px"
    };
  };

  var layout = (function (selector, componentVars) {
    var thumbSize = Math.max(componentVars.thumb_size, 2 * componentVars.thumb_border_width);
    var scaledThumbDiff = (componentVars.active_thumb_scale - 1) * thumbSize / 2;
    var barOffset = thumbSize / 2;
    var scaledBorderWidth = Math.max(1, componentVars.thumb_border_width / componentVars.active_thumb_scale);
    var thumbTouchSize = componentVars.thumb_touch_size;
    var stepsOffset = barOffset - 1;

    return [_defineProperty({}, selector, [polytheneCoreCss.flex.layoutHorizontal, polytheneCoreCss.flex.flexGrow(1), {
      userSelect: "none",
      height: componentVars.height + "px",
      marginTop: (componentVars.height - componentVars.track_height) / 2 + "px ",
      alignItems: "center",

      " > .pe-icon": [polytheneCoreCss.flex.layoutCenter, {
        height: componentVars.height + "px"
      }],

      " .pe-slider__track": [polytheneCoreCss.flex.layoutHorizontal, polytheneCoreCss.flex.flexGrow(1), polytheneCoreCss.mixin.defaultTransition("transform", componentVars.animation_duration), {
        userSelect: "none",
        position: "relative",
        height: componentVars.track_height + "px",
        margin: "0 " + componentVars.side_spacing + "px",
        outline: 0
      }],
      " div + .pe-slider__track": {
        margin: "0 " + componentVars.horizontal_layout_side_spacing + "px"
      },

      " .pe-slider__control": [polytheneCoreCss.flex.selfCenter, polytheneCoreCss.mixin.defaultTransition("transform, background", ".200s"), {
        transform: "scale(1)",
        userSelect: "none",
        width: thumbSize + "px",
        height: thumbSize + "px",
        lineHeight: 0,
        borderRadius: "50%",
        outline: 0,
        zIndex: 1,
        position: "relative",

        // touch area
        ":before": [polytheneCoreCss.mixin.defaultTransition("background-color", componentVars.animation_duration), {
          content: "\"\"",
          position: "absolute",
          borderRadius: "50%",
          left: -thumbTouchSize / 2 + thumbSize / 2 + "px",
          top: -thumbTouchSize / 2 + thumbSize / 2 + "px",
          width: thumbTouchSize + "px",
          height: thumbTouchSize + "px"
        }],

        // border
        ":after": [polytheneCoreCss.mixin.defaultTransition("border", componentVars.animation_duration), positionBorder(thumbSize, componentVars.thumb_border_width, false), {
          content: "\"\"",
          position: "absolute",
          borderRadius: "50%",
          borderStyle: "solid"
        }]
      }],

      " .pe-slider__thumb": [polytheneCoreCss.mixin.defaultTransition("opacity", componentVars.animation_duration), polytheneCoreCss.mixin.fit(), {
        "&, .pe-icon": {
          width: "inherit",
          height: "inherit"
        }
      }],

      " .pe-slider__label": {
        height: componentVars.height + "px",
        lineHeight: componentVars.height + "px",
        minWidth: polytheneTheme.vars.unit_icon_size + "px",
        textAlign: "center",
        fontSize: "16px",
        fontWeight: polytheneTheme.vars.font_weight_medium
      },

      " .pe-slider__track-part": [polytheneCoreCss.flex.flex(), {
        userSelect: "none",
        height: componentVars.bar_height + "px",
        margin: (componentVars.track_height - componentVars.bar_height) / 2 + "px 0",
        overflow: "hidden" // Firefox otherwise uses 6x at 0%
      }],

      " .pe-slider__track-value, .pe-slider__track-rest": polytheneCoreCss.flex.layoutHorizontal,

      " .pe-slider__track-bar": [polytheneCoreCss.flex.flex(), {
        position: "relative",
        overflow: "hidden"
      }],
      " .pe-slider__track-bar-value": [polytheneCoreCss.flex.flex(), polytheneCoreCss.mixin.defaultTransition("transform, background-color", componentVars.animation_duration), {
        height: componentVars.bar_height + "px"
      }],
      " .pe-slider__track-value .pe-slider__track-bar": {
        marginLeft: barOffset + "px"
      },
      " .pe-slider__track-rest .pe-slider__track-bar": {
        marginRight: barOffset + "px"
      },

      " .pe-slider__ticks": [polytheneCoreCss.flex.layoutJustified, {
        userSelect: "none",
        position: "absolute",
        width: "calc(100% - " + 2 * stepsOffset + "px)",
        height: componentVars.bar_height + "px",
        left: 0,
        top: componentVars.height / 2 - 1 + "px",
        margin: "0 " + stepsOffset + "px",
        pointerEvents: "none"
      }],

      " .pe-slider__ticks-tick": {
        width: componentVars.step_width + "px",
        height: componentVars.bar_height + "px"
      },

      " .pe-slider__pin": [polytheneCoreCss.mixin.defaultTransition("transform", ".11s"), {
        transform: "translateZ(0) scale(0) translate(0, 0)",
        transformOrigin: "bottom",
        position: "absolute",
        zIndex: 1,
        width: componentVars.pin_width + "px",
        height: 0,
        left: 0, // set in js
        top: 0,
        margin: "0 " + stepsOffset + "px 0 " + (stepsOffset - componentVars.pin_width / 2 + 1) + "px",
        pointerEvents: "none",

        "::before": {
          transform: "rotate(-45deg)",
          content: "\"\"",
          position: "absolute",
          top: 0,
          left: 0,
          width: componentVars.pin_width + "px",
          height: componentVars.pin_width + "px",
          borderRadius: "50% 50% 50% 0",
          backgroundColor: "inherit"
        },
        "::after": {
          content: "attr(value)",
          position: "absolute",
          top: 0,
          left: 0,
          width: componentVars.pin_width + "px",
          height: componentVars.pin_height + "px",
          textAlign: "center",
          color: "#fff",
          fontSize: componentVars.pin_font_size + "px",
          lineHeight: componentVars.pin_width + "px"
        }
      }],

      ".pe-slider--active:not(.pe-slider--ticks)": {
        " .pe-slider__control": {
          transform: "scale(" + componentVars.active_thumb_scale + ")",
          borderWidth: scaledBorderWidth + "px"
        },
        // left side
        " .pe-slider__track-value .pe-slider__track-bar-value": {
          transform: "translateX(" + -scaledThumbDiff + "px)"
        },
        // right side
        " .pe-slider__track-rest .pe-slider__track-bar-value": {
          transform: "translateX(" + scaledThumbDiff + "px)"
        }
      },

      ".pe-slider--pin.pe-slider--active, &.pe-slider--pin.pe-slider--focus": {
        " .pe-slider__pin": {
          transform: "translateZ(0) scale(1) translate(0, -24px)"
        },
        " .pe-slider__control": {
          transform: "scale(" + componentVars.active_pin_thumb_scale + ")"
        }
      },

      ":not(.pe-slider--disabled)": {
        " .pe-slider__control": {
          cursor: "pointer"
        },
        ".pe-slider--track": {
          " .pe-slider__track": {
            cursor: "pointer"
          }
        }
      },

      ".pe-slider--disabled": {
        " .pe-slider__control": {
          transform: "scale(" + componentVars.disabled_thumb_scale + ")",
          borderWidth: 0
        },
        " .pe-slider__control:after": [positionBorder(thumbSize, 1 / componentVars.disabled_thumb_scale * componentVars.thumb_border_width, true)]
      }
    }])];
  });

  function _defineProperty$1(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

  var style = function style(scopes, selector, componentVars, tint) {
    return [_defineProperty$1({}, scopes.map(function (s) {
      return s + selector;
    }).join(","), {
      color: componentVars["color_" + tint + "_thumb_on"], // override by specifying "color"

      " .pe-slider__control": {
        "&:after": {
          borderColor: "transparent"
        }
      },
      " .pe-slider__track-bar-value": {
        background: componentVars["color_" + tint + "_track_inactive"]
      },

      " .pe-slider__ticks-tick": {
        background: componentVars["color_" + tint + "_tick"]
      },

      " .pe-slider__pin": {
        backgroundColor: "currentcolor"
      },

      " .pe-icon": {
        color: componentVars["color_" + tint + "_disabled_icon"]
      },

      " .pe-slider__label": {
        color: componentVars["color_" + tint + "_disabled_label"]
      },

      // states

      "&.pe-slider--active": {
        " .pe-slider__track-bar-value": {
          background: componentVars["color_" + tint + "_track_active"]
        }
      },

      ".pe-slider--disabled": {
        " .pe-slider__control": {
          background: componentVars["color_" + tint + "_thumb_inactive"]
        }
      },

      "&:not(.pe-slider--disabled)": {
        " .pe-slider__control": {
          backgroundColor: componentVars["color_" + tint + "_thumb_background"] || "currentcolor",

          "&:before": {
            opacity: componentVars["color_" + tint + "_thumb_off_focus_opacity"]
          }
        },
        " .pe-slider__track-value .pe-slider__track-bar-value": {
          background: "currentcolor"
        },
        "&.pe-slider--focus.pe-slider--min:not(.pe-slider--pin) .pe-slider__control:before,\
      &.pe-slider--min:not(.pe-slider--pin) .pe-slider__control:focus:before": {
          backgroundColor: componentVars["color_" + tint + "_thumb_off_focus"]
        },
        "&.pe-slider--focus:not(.pe-slider--min):not(.pe-slider--pin) .pe-slider__control:before,\
      &:not(.pe-slider--min):not(.pe-slider--pin) .pe-slider__control:focus:before": {
          backgroundColor: "currentcolor",
          opacity: componentVars["color_" + tint + "_thumb_on_focus_opacity"]
        },
        " .pe-icon": {
          color: componentVars["color_" + tint + "_icon"]
        },
        " .pe-slider__label": {
          color: componentVars["color_" + tint + "_label"]
        }
      },

      "&.pe-slider--min:not(.pe-slider--disabled)": {
        " .pe-slider__control": {
          backgroundColor: "transparent"
        },
        " .pe-slider__thumb": {
          opacity: 0
        },
        " .pe-slider__control:after": {
          borderColor: componentVars["color_" + tint + "_track_inactive"]
        },
        "&.pe-slider--active .pe-slider__control:after": {
          borderColor: componentVars["color_" + tint + "_track_active"]
        },
        "&.pe-slider--ticks": {
          " .pe-slider__control": {
            backgroundColor: componentVars["color_" + tint + "_tick"]
          },
          " .pe-slider__control:after": {
            borderColor: "transparent"
          }
        },
        " .pe-slider__pin": {
          backgroundColor: componentVars["color_" + tint + "_track_inactive"]
        }
      }
    })];
  };

  var color = (function (selector, componentVars) {
    return [style([".pe-dark-tone", ".pe-dark-tone "], selector, componentVars, "dark"), // has/inside dark tone
    style(["", ".pe-light-tone", ".pe-light-tone "], selector, componentVars, "light")];
  });

  var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

  var fns = [layout, color];
  var selector = "." + classes.component;

  var addStyle = function addStyle(customSelector, customVars) {
    return polytheneCoreCss.styler.generateStyles([customSelector, selector], _extends({}, polytheneCoreSlider.vars, customVars), fns);
  };

  var getStyle = function getStyle(customSelector, customVars) {
    return customSelector ? polytheneCoreCss.styler.createStyleSheets([customSelector, selector], _extends({}, polytheneCoreSlider.vars, customVars), fns) : polytheneCoreCss.styler.createStyleSheets([selector], polytheneCoreSlider.vars, fns);
  };

  polytheneCoreCss.styler.generateStyles([selector], polytheneCoreSlider.vars, fns);

  exports.addStyle = addStyle;
  exports.getStyle = getStyle;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=polythene-css-slider.js.map
